Polynomial Eigenvalue Problem Solvers - PEP

slepc-3.18.0 2022-10-01
Report Typos and Errors

## Polynomial Eigenvalue Problem Solvers - PEP: Examples NLEVP

The Polynomial Eigenvalue Problem (PEP) solver is the object provided by SLEPc for specifying a polynomial eigenvalue problem. Apart from the specific solvers for this type of problems, there is an EPS-based solver, i.e., it uses a solver from EPS to solve a generalized eigenproblem obtained after linearization.

As in the other solver objects, users can set various options at runtime via the options database (e.g., `-pep_nev 4 -pep_type linear`). Options can also be set directly in application codes by calling the corresponding routines (e.g., PEPSetDimensions() / PEPSetType()).

acoustic_wave_1d.c: Quadratic eigenproblem from an acoustics application (1-D)
acoustic_wave_2d.c: Quadratic eigenproblem from an acoustics application (2-D)
butterfly.c: Quartic polynomial eigenproblem with T-even structure
damped_beam.c: Quadratic eigenproblem from the vibrarion analysis of a beam
loaded_string.c: Finite element model of a loaded vibrating string
pdde_stability.c: Stability analysis of a discretized partial delay-differential equation
planar_waveguide.c: FEM solution of the propagation constants in a six-layer planar waveguide
sleeper.c: Oscillations of a rail track resting on sleepers
spring.c: FEM model of a damped mass-spring system
wiresaw.c: Vibration analysis of a wiresaw